
#include <improv/improv.h>
#include <stdio.h>

static int update_signal(ImprovObject *obj,int signal_type,void *arg);

ImprovClass improv_socket_class={
	name:	"ImprovSocket",
	size:	sizeof(ImprovSocket),
	parent:	&improv_object_class,
};

ImprovSocket *improv_socket_new(void)
{
	ImprovSocket *it;

	it=(ImprovSocket *)improv_object_new(&improv_socket_class);

	return it;
}

int improv_socket_read(ImprovSocket *sock,ImprovData **x,int request)
{
	ImprovData *data;
	ImprovData *next;

	data=sock->next;
	if(!data)
		return 0;

	next=data->next;

	if(next){
		next->prev=NULL;
	}
	sock->next=next;

	data->sock=NULL;
	data->next=NULL;
	data->prev=NULL;

	sock->n_data--;

	*x=data;

	return 1;
}

int improv_socket_peek(ImprovSocket *sock,ImprovData **x)
{
	ImprovData *data;

	data=sock->next;
	if(!data)
		return 0;

	*x=data;

	return 1;
}

int improv_socket_write(ImprovSocket *sock,ImprovData *x)
{
	ImprovData *data;

	data=improv_data_clone(x);

	return improv_socket_write_nocopy(sock,data);
}

int improv_socket_write_nocopy(ImprovSocket *sock,ImprovData *data)
{
	ImprovData *prev;

	prev=sock->prev;
	if(prev){
		prev->next=data;
	}else{
		sock->next=data;
		sock->prev=data;
	}
	data->prev=prev;
	data->next=NULL;

	data->sock=IMPROV_OBJECT(sock);

	sock->n_data++;

	if(sock->n_data==1){
		improv_signal_emit(IMPROV_OBJECT(sock),ImprovSignalUpdate);
	}

	return 1;
}

int improv_socket_connect(ImprovSocket *from,ImprovSocket *to)
{
	from->to=to;
	to->from=from;

	improv_signal_connect(IMPROV_OBJECT(to),ImprovSignalUpdateRequest,
		improv_signal_forward,from);

	improv_signal_connect(IMPROV_OBJECT(from),ImprovSignalUpdate,
		update_signal,to);

	return 0;
}

static int update_signal(ImprovObject *obj,int signal_type,void *arg)
{
	ImprovSocket *in=IMPROV_SOCKET(obj);
	ImprovData *data;

	while(improv_socket_read(in,&data,0)){
		improv_socket_write_nocopy(in->to,data);
	}

	return 0;
}

