
#include <math.h>
#include <improv/improv.h>

#define TEMP_KELVIN_CELSIUS 273.15

ImprovClass improv_thermocouple_class={
	name:	"ImprovThermocouple",
	size:	sizeof(ImprovThermocouple),
	parent:	&improv_object_class,
};

static int do_update(ImprovThermocouple *t);
static int update_in(ImprovObject *obj,int signal_type,void *arg);
static int update_ref(ImprovObject *obj,int signal_type,void *arg);
static int update_request(ImprovObject *obj,int signal_type,void *arg);


ImprovThermocouple *improv_thermocouple_new(const char *type)
{
	ImprovThermocouple *it;

	it=IMPROV_THERMOCOUPLE(improv_object_new(&improv_thermocouple_class));

	it->type=tc_find_by_name(type);

	it->in=improv_socket_new();
	it->out=improv_socket_new();
	it->ref=improv_socket_new();

	it->type=0;

	return 0;
}


static int update_request(ImprovObject *obj,int signal_type,void *arg)
{
	ImprovThermocouple *t=IMPROV_THERMOCOUPLE(obj);

	improv_signal_emit(IMPROV_OBJECT(t->in),ImprovSignalUpdateRequest);
	improv_signal_emit(IMPROV_OBJECT(t->ref),ImprovSignalUpdateRequest);

	if(t->in_data){
		improv_object_destroy(IMPROV_OBJECT(t->in_data));
		t->in_data=NULL;
	}
	if(t->ref_data){
		improv_object_destroy(IMPROV_OBJECT(t->ref_data));
		t->ref_data=NULL;
	}

	return 0;
}

static int update_in(ImprovObject *obj,int signal_type,void *arg)
{
	ImprovThermocouple *t=IMPROV_THERMOCOUPLE(obj);

	if(t->in_data){
		improv_object_destroy(IMPROV_OBJECT(t->in_data));
		t->in_data=NULL;
	}
	improv_socket_read(t->in,&t->in_data,0);

	if(t->ref_data)
		do_update(t);

	return 0;
}

static int update_ref(ImprovObject *obj,int signal_type,void *arg)
{
	ImprovThermocouple *t=IMPROV_THERMOCOUPLE(obj);

	if(t->ref_data){
		improv_object_destroy(IMPROV_OBJECT(t->ref_data));
		t->in_data=NULL;
	}
	improv_socket_read(t->ref,&t->ref_data,0);

	if(t->ref_data)
		do_update(t);

	return 0;
}

static int do_update(ImprovThermocouple *t)
{
	ImprovData *x;

	x=improv_data_new();

	improv_socket_write_nocopy(t->out,x);

	improv_object_destroy(IMPROV_OBJECT(t->in_data));
	t->in_data=NULL;
	improv_object_destroy(IMPROV_OBJECT(t->ref_data));
	t->ref_data=NULL;

	return 0;
}



