/*
    thermocouple.h
    header file for thermocouple library

    libtc - a thermocouple library
    Copyright (C) 1998 Mark Rose <mrose@stm.lbl.gov>
    Copyright (C) 1999 David A. Schleef <ds@stm.lbl.gov>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#ifndef _THERMOCOUPLE_H_
#define _THERMOCOUPLE_H_


typedef struct thermocouple_struct *thermocouple_t;

thermocouple_t tc_find_by_name(const char *name);
thermocouple_t tc_browse(thermocouple_t type);

double tc_emf_to_temp(thermocouple_t type,double temp);
double tc_temp_to_emf(thermocouple_t type,double emf);

char *tc_name(thermocouple_t type);
void tc_emf_range(thermocouple_t type,double *min,double *max);
void tc_temp_range(thermocouple_t type,double *min,double *max);



typedef struct tc_table_struct tc_table;

struct tc_table_struct
{
	struct tc_table_struct *next;

	double min, max;		// min & max emfs (E->T) or temps (T-E)
	int poly;			// polynomial or lookup table
	int e2t;			// thermovoltage to temperature
	int size;			// number of coefficients or table size
	double *d;			// coefficients or table
	double a0,a1,a2;		// exponential "alpha" factors
};


struct thermocouple_struct
{
	struct thermocouple_struct *next;

	char		*name;		// type of thermocouple ('E',etc...)

	tc_table*	emf_to_temp;	// a table for each range
	tc_table*	temp_to_emf;	// a table for each range
};


#endif

