/*
    /usr/include/units.h
    header file for physical units library

    Physical Units Library - libunits
    Copyright (C) 1998 David A. Schleef <ds@stm.lbl.gov>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#ifndef _UNITS_H_
#define _UNITS_H_

#ifdef __cplusplus
extern "C" {
#endif

#define units_compatible(a,b)	((a).base==(b).base)
#define convert_to_base(a,b)		((b)*(a).to_base)
#define convert_from_base(a,b)		((b)*(a).from_base)

#define UNIT_PER_ROOT_HERTZ		0x0001
#if FUTURE
#define UNIT_RELATIVE			0x0002
#define UNIT_RADIANS			0x0004
#endif

typedef struct unit_struct unit;
typedef struct baseunit_struct baseunit;

struct unit_struct {
	baseunit *base;
	double to_base;
	double from_base;
};

/*
 *  function prototypes
 */

/* return a unit corresponding to a given name */
unit unit_by_name(char *name);

/* return a unit corresponding to a given base name */
unit unit_by_basename(char *basename);

/* multiply two units */
unit unit_multiply(unit a, unit b);

/* divide units */
unit unit_divide(unit a, unit b);


#ifdef _UNITS_INTERNAL_

/*
 *  This section is part of the internal structure of the library.
 *  It is here for the convenience of the author.
 *
 *  No user serviceable parts inside.
 */

/*  Number of primitive units  */
#define N_PRIM		5
/* 0-length 1-mass 2-time 3-current 4-temperature */
/* soon: 5-angle */

typedef struct baseunit_lookup_struct baseunit_lookup;
typedef struct unit_lookup_struct unit_lookup;

struct baseunit_struct {
	int flags;
	baseunit *next;
	int exp[N_PRIM];
};

struct baseunit_lookup_struct{
	char *baseunit_name;
	int e0,e1,e2,e3,e4;
};

struct unit_lookup_struct{
	char *unit_name;
	char *baseunit_name;
	double factor;
};

extern baseunit *baseunits;
extern unit unit0;
extern baseunit baseunit0;

/* returns a pointer to a persistent baseunit, possibly
 * creating it. */
baseunit *find_baseunit(baseunit *);

/* creates a new persistent baseunit */
baseunit *new_baseunit(baseunit *);

/* compate baseunits */
int compare_baseunits(baseunit *,baseunit *);

/* return a standard unit corresponding to a baseunit */
unit unit_standard(baseunit *);

/* return a base unit by name */
baseunit *baseunit_by_name(char *name);

/* multiply base units */
baseunit *baseunit_multiply(baseunit *a,baseunit *b);

/* divide base units */
baseunit *baseunit_divide(baseunit *a,baseunit *b);

#endif /* _UNITS_INTERNAL_ */

#ifdef __cplusplus
};
#endif

#endif /* _UNITS_H_ */

