// Type 'E' Thermocouple Polynomials
//
// Source: Omega Engineering "Thermocouple Reference Tables", based on ITS-90
// 
// Errors: 
//		E -> t (-200C to 0C)	+0.03C to -0.01C
//		E -> t (0C to 1000C)	+0.02C to -0.02C
//
// Notes (see the Omega handbook for a MUCH more detailed account)
//
// "It should be stressed that type E thermocouple materials that conform
// closely to the high temperature tabular values may not necessarily
// conform closely at low temperatures (below 0C) and vice versa.  If type
// E thermocouples are to be used for accurate measurements both above and
// below 0C, then the material must be calibrated in the full temperature
// range, both above and below 0C.  Special selection of materials will
// usually be required."


#define tc_S_type 'S'
#define tc_S_tables 5

static double S_coeff_0[11] = {
	+0.0000000000e+00,
	+5.8665508710e+01,
	+4.5032275582e-02,
	+2.8908407212e-05,
	-3.3056896652e-07,
	+6.5024403270e-10,
	-1.9197495504e-13,
	-1.2536600497e-15,
	+2.1489217569e-18,
	-1.4388041782e-21,
	+3.5960899481e-25
};

static double S_coeff_1[14] = {
	+0.0000000000e+00,
	+5.8665508708e+01,
	+4.5410977124e-02,
	-7.7998048686e-04,
	-2.5800160843e-05,
	-5.9452583057e-07,
	-9.3214058667e-09,
	-1.0287605534e-10,
	-8.0370123621e-13,
	-4.3979497391e-15,
	-1.6414776355e-17,
	-3.9673619516e-20,
	-5.5827328721e-23,
	-3.4657842013e-26
};

static double S_coeff_2[10] = {
	+0.0000000e+00,
	+1.7057035e-02,
	-2.3301759e-07,
	+6.5435585e-12,
	-7.3562749e-17,
	-1.7896001e-21,
	+8.4036165e-26,
	-1.3735879e-30,
	+1.0629823e-35,
	-3.2447087e-41
};

static double S_coeff_3[9] = {
	+0.0000000e+00,
	+1.6977288e-02,
	-4.3514970e-07,
	-1.5859697e-10,
	-9.2502871e-14,
	-2.6084314e-17,
	-4.1360199e-21,
	-3.4034030e-25,
	-1.1564890e-29
};

static double S_coeff_4[9] = {
	+2.6070302e+06,
	+7.9852930e+02,
	+3.9066870e-02,
	-6.1244614e-06,
	+1.8514798e-10,
	+1.2195908e-13,
	+2.3176544e-19,
	-9.6989370e-22,
	-4.2394815e-26
};

static tc_table tc_S_e2t_2 = {
	next: NULL,
	min: 0,			// min
	max: 76373,			// max
	poly: 1,  			// polynomial
	e2t: 1,  			// e -> t
	size: 10,			// number of coefficients
	d: S_coeff_2,		// coefficients
	a0: 0, 			// alpha_0
	a1: 0, 			// alpha_1
	a2: 0  			// alpha_2
};

static tc_table tc_S_e2t_3 = {
	next: &tc_S_e2t_2,
	min: -8825,			// min
	max: 0,			// max
	poly: 1,  			// polynomial
	e2t: 1,  			// e -> t
	size: 9,			// number of coefficients
	d: S_coeff_3,		// coefficients
	a0: 0, 			// alpha_0
	a1: 0, 			// alpha_1
	a2: 0  			// alpha_2
};

static tc_table tc_S_e2t_4 = {
	next: &tc_S_e2t_3,
	min: -9875,			// min
	max: -8825,			// max
	poly: 1,  			// polynomial
	e2t: 1,  			// e -> t
	size: 9,			// number of coefficients
	d: S_coeff_4,		// coefficients
	a0: 0, 			// alpha_0
	a1: 0, 			// alpha_1
	a2: 0  			// alpha_2
};

#define TC_S_E2T &tc_S_e2t_4

static tc_table tc_S_t2e_0 = {
	next: NULL,
	min: 0,			// min
	max: 1000,			// max
	poly: 1,  			// polynomial
	e2t: 0,  			// t -> e
	size: 11,			// number of coefficients
	d: S_coeff_0,		// coefficients
	a0: 0, 			// alpha_0
	a1: 0, 			// alpha_1
	a2: 0  			// alpha_2
};

static tc_table tc_S_t2e_1 = {
	next: &tc_S_t2e_0,
	min: -270,			// min
	max: 0,			// max
	poly: 1,  			// polynomial
	e2t: 0,  			// t -> e
	size: 14,			// number of coefficients
	d: S_coeff_1,		// coefficients
	a0: 0, 			// alpha_0
	a1: 0, 			// alpha_1
	a2: 0  			// alpha_2
};

#define TC_S_T2E &tc_S_t2e_1

